"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const path_1 = require("path");
const zod_1 = require("zod");
const __1 = require("..");
const config = fs_1.promises
    .readFile(path_1.join(__dirname, `..`, `..`, `config.test.json`), {
    encoding: `utf-8`,
})
    .then((json) => JSON.parse(json))
    .then(zod_1.z.object({
    username: zod_1.z.string(),
    password: zod_1.z.string(),
    applets: zod_1.z.array(zod_1.z.object({
        appletId: zod_1.z.string(),
        appletPassword: zod_1.z.string(),
    })),
}).parse);
describe(`Client`, () => {
    test(`getAuth`, async () => {
        const { username, password } = await config;
        await expect(__1.Client.createClient(username, `wrong password`)).rejects.toBeTruthy();
        await expect(__1.Client.createClient(`wrong username`, password)).rejects.toBeTruthy();
        const client = await __1.Client.createClient(username, password);
        await expect(client.getAuth().then(__1.Authentication.parse)).resolves.toBeTruthy();
    });
    test(`getAppletInfo`, async () => {
        const { username, password, applets } = await config;
        const client = await __1.Client.createClient(username, password);
        await Promise.all(applets.map(async ({ appletId }) => {
            await expect(client.getAppletInfo(appletId).then(__1.AppletInfo.parse)).resolves.toBeTruthy();
        }));
    });
    test(`getAppletData`, async () => {
        const { username, password, applets } = await config;
        const client = await __1.Client.createClient(username, password);
        await Promise.all(applets.map(async ({ appletId }) => {
            await expect(client.getAppletData(appletId).then(__1.AppletData.parse)).resolves.toBeTruthy();
        }));
    });
});
//# sourceMappingURL=Client.test.js.map