"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const path_1 = require("path");
const zod_1 = require("zod");
const __1 = require("..");
const config = fs_1.promises
    .readFile(path_1.join(__dirname, `..`, `..`, `config.test.json`), {
    encoding: `utf-8`,
})
    .then((json) => JSON.parse(json))
    .then(zod_1.z.object({
    username: zod_1.z.string(),
    password: zod_1.z.string(),
    applets: zod_1.z.array(zod_1.z.object({
        appletId: zod_1.z.string(),
        appletPassword: zod_1.z.string(),
    })),
}).parse);
describe(`Encryption`, () => {
    test(`decryptAppletResponses`, async () => {
        const { username, password, applets } = await config;
        const client = await __1.Client.createClient(username, password);
        await Promise.all(applets.map(async ({ appletId, appletPassword }) => {
            const [appletInfo, appletData] = await Promise.all([
                client.getAppletInfo(appletId),
                client.getAppletData(appletId),
            ]);
            const responses = __1.decryptAppletResponses(appletInfo, appletData, appletPassword);
            expect(responses).toBeInstanceOf(Array);
            for (const response of responses) {
                expect(typeof response.responseId).toEqual(`string`);
                expect(typeof response.data).not.toEqual(`undefined`);
            }
        }));
    });
});
//# sourceMappingURL=Encryption.test.js.map