"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Client = void 0;
const tslib_1 = require("tslib");
const node_fetch_1 = tslib_1.__importStar(require("node-fetch"));
const Responses_1 = require("./Responses");
class Client {
    constructor(authToken) {
        this.refreshToken = async (username, password) => {
            this.authToken = await Client.fetchAuthToken(username, password);
        };
        this.fetch = (path, info = {}) => {
            var _a;
            return node_fetch_1.default(Client.url(path), {
                ...info,
                headers: {
                    ...((_a = info.headers) !== null && _a !== void 0 ? _a : {}),
                    "Girder-Token": this.authToken.token,
                },
            }).then((response) => response.json());
        };
        this.getAuth = () => this.fetch(`/api/v1/user/authentication`).then(Responses_1.Authentication.parse);
        this.getAppletInfo = (appletId) => this.fetch(`/api/v1/applet/${appletId}?retrieveSchedule=true&retrieveAllEvents=true&retrieveItems=true`).then(Responses_1.AppletInfo.parse);
        this.getAppletData = (appletId) => this.fetch(`/api/v1/applet/${appletId}/data?users=`).then(Responses_1.AppletData.parse);
        this.authToken = authToken;
    }
}
exports.Client = Client;
Client.baseURL = `https://api.mindlogger.org`;
Client.url = (path) => new URL(path, Client.baseURL);
Client.fetchAuthToken = async (username, password) => {
    const { authToken } = await node_fetch_1.default(Client.url(`/api/v1/user/authentication?lang=en_US`), {
        method: `get`,
        headers: new node_fetch_1.Headers({
            "Girder-Authorization": `Basic ${Buffer.from(`${username}:${password}`).toString(`base64`)}`,
        }),
    })
        .then((response) => response.json())
        .then(Responses_1.Authentication.parse);
    return authToken;
};
Client.createClient = async (username, password) => {
    const token = await Client.fetchAuthToken(username, password);
    return new Client(token);
};
//# sourceMappingURL=Client.js.map