"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.decryptAppletResponses = void 0;
const tslib_1 = require("tslib");
// See https://github.com/ChildMindInstitute/mindlogger-admin/blob/3ccaeb6e23820d480658155014c66179bc7bd112/src/Components/Utils/encryption/encryption.vue#L8
const crypto_1 = require("crypto");
const buffer_1 = tslib_1.__importDefault(require("../../node_modules/buffer"));
const BufferPolyfillToString = buffer_1.default.Buffer.prototype.toString;
const createAppletPrivateKey = (appletPassword, accountId) => {
    const buf1 = crypto_1.createHash(`sha512`).update(appletPassword).digest();
    const buf2 = crypto_1.createHash(`sha512`).update(accountId).digest();
    const s1 = BufferPolyfillToString.apply(buf1);
    const s2 = BufferPolyfillToString.apply(buf2);
    const s3 = s1 + s2;
    const result = Buffer.from(s3);
    return result;
};
const createAppletRespondentKey = (appletPrime, appletPrivateKey, appletRespondentPublicKey) => {
    const appletRespondentKey = crypto_1.createDiffieHellman(appletPrime);
    appletRespondentKey.setPrivateKey(appletPrivateKey);
    const appletRespondentSecret = appletRespondentKey.computeSecret(appletRespondentPublicKey);
    return crypto_1.createHash(`sha256`).update(appletRespondentSecret).digest();
};
const decryptAppletResponse = (respondentKey, responseData) => {
    const [ivHex, ...parts] = responseData.split(`:`);
    const iv = Buffer.from(ivHex, `hex`);
    const encryptedData = Buffer.from(parts.join(`:`), `hex`);
    const decipher = crypto_1.createDecipheriv(`aes-256-cbc`, respondentKey, iv);
    const chunks = [decipher.update(encryptedData)];
    chunks.push(decipher.final());
    return Buffer.concat(chunks).toString();
};
const decryptAppletResponses = (appletInfo, appletData, appletPassword) => {
    const appletPrime = Buffer.from(appletInfo.applet.encryption.appletPrime);
    const appletPrivateKey = createAppletPrivateKey(appletPassword, appletInfo.accountId);
    const respondentKeys = appletData.keys.map((appletRespondentPublicKey) => createAppletRespondentKey(appletPrime, appletPrivateKey, Buffer.from(appletRespondentPublicKey)));
    return Object.entries(appletData.dataSources).map(([responseId, { data: responseData, key: respondentKeyIndex }]) => {
        const respondentKey = respondentKeys[respondentKeyIndex];
        if (!respondentKey) {
            throw new Error(`respondentKey not found: ${respondentKeyIndex}`);
        }
        return {
            data: JSON.parse(decryptAppletResponse(respondentKey, responseData)),
            responseId,
        };
    });
};
exports.decryptAppletResponses = decryptAppletResponses;
//# sourceMappingURL=Encryption.js.map