import { z } from "zod";
export declare const AuthToken: z.ZodObject<{
    expires: z.ZodString;
    token: z.ZodString;
}, "strip", z.ZodTypeAny, {
    expires: string;
    token: string;
}, {
    expires: string;
    token: string;
}>;
export declare type AuthToken = z.infer<typeof AuthToken>;
export declare const Authentication: z.ZodObject<{
    account: z.ZodObject<{
        accountId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        accountId: string;
    }, {
        accountId: string;
    }>;
    authToken: z.ZodObject<{
        expires: z.ZodString;
        token: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        expires: string;
        token: string;
    }, {
        expires: string;
        token: string;
    }>;
    user: z.ZodObject<{
        email: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        email: string;
    }, {
        email: string;
    }>;
}, "strip", z.ZodTypeAny, {
    account: {
        accountId: string;
    };
    authToken: {
        expires: string;
        token: string;
    };
    user: {
        email: string;
    };
}, {
    account: {
        accountId: string;
    };
    authToken: {
        expires: string;
        token: string;
    };
    user: {
        email: string;
    };
}>;
export declare type Authentication = z.infer<typeof Authentication>;
export declare const AppletInfo: z.ZodObject<{
    accountId: z.ZodString;
    applet: z.ZodObject<{
        encryption: z.ZodObject<{
            appletPrime: z.ZodArray<z.ZodNumber>;
            appletPublicKey: z.ZodArray<z.ZodNumber>;
            base: z.ZodArray<z.ZodNumber>;
        }, "strip", z.ZodTypeAny, {
            appletPrime: number[];
            appletPublicKey: number[];
            base: number[];
        }, {
            appletPrime: number[];
            appletPublicKey: number[];
            base: number[];
        }>;
    }, "strip", z.ZodTypeAny, {
        encryption: {
            appletPrime: number[];
            appletPublicKey: number[];
            base: number[];
        };
    }, {
        encryption: {
            appletPrime: number[];
            appletPublicKey: number[];
            base: number[];
        };
    }>;
    items: z.ZodRecord<z.ZodObject<{
        "@id": z.ZodString;
        "reprolib:terms/inputType": z.ZodArray<z.ZodObject<{
            "@type": z.ZodString;
            "@value": z.ZodString;
        }, "strip", z.ZodTypeAny, {
            "@type": string;
            "@value": string;
        }, {
            "@type": string;
            "@value": string;
        }>>;
        "reprolib:terms/responseOptions": z.ZodArray<z.ZodObject<{
            "reprolib:terms/valueType": z.ZodOptional<z.ZodArray<z.ZodObject<{
                "@id": z.ZodString;
            }, "strip", z.ZodTypeAny, {
                "@id": string;
            }, {
                "@id": string;
            }>>>;
        }, "strip", z.ZodTypeAny, {
            "reprolib:terms/valueType"?: {
                "@id": string;
            }[] | undefined;
        }, {
            "reprolib:terms/valueType"?: {
                "@id": string;
            }[] | undefined;
        }>>;
        "schema:question": z.ZodArray<z.ZodObject<{
            "@language": z.ZodString;
            "@value": z.ZodString;
        }, "strip", z.ZodTypeAny, {
            "@value": string;
            "@language": string;
        }, {
            "@value": string;
            "@language": string;
        }>>;
    }, "strip", z.ZodTypeAny, {
        "@id": string;
        "reprolib:terms/inputType": {
            "@type": string;
            "@value": string;
        }[];
        "reprolib:terms/responseOptions": {
            "reprolib:terms/valueType"?: {
                "@id": string;
            }[] | undefined;
        }[];
        "schema:question": {
            "@value": string;
            "@language": string;
        }[];
    }, {
        "@id": string;
        "reprolib:terms/inputType": {
            "@type": string;
            "@value": string;
        }[];
        "reprolib:terms/responseOptions": {
            "reprolib:terms/valueType"?: {
                "@id": string;
            }[] | undefined;
        }[];
        "schema:question": {
            "@value": string;
            "@language": string;
        }[];
    }>>;
}, "strip", z.ZodTypeAny, {
    items: Record<string, {
        "@id": string;
        "reprolib:terms/inputType": {
            "@type": string;
            "@value": string;
        }[];
        "reprolib:terms/responseOptions": {
            "reprolib:terms/valueType"?: {
                "@id": string;
            }[] | undefined;
        }[];
        "schema:question": {
            "@value": string;
            "@language": string;
        }[];
    }>;
    accountId: string;
    applet: {
        encryption: {
            appletPrime: number[];
            appletPublicKey: number[];
            base: number[];
        };
    };
}, {
    items: Record<string, {
        "@id": string;
        "reprolib:terms/inputType": {
            "@type": string;
            "@value": string;
        }[];
        "reprolib:terms/responseOptions": {
            "reprolib:terms/valueType"?: {
                "@id": string;
            }[] | undefined;
        }[];
        "schema:question": {
            "@value": string;
            "@language": string;
        }[];
    }>;
    accountId: string;
    applet: {
        encryption: {
            appletPrime: number[];
            appletPublicKey: number[];
            base: number[];
        };
    };
}>;
export declare type AppletInfo = z.infer<typeof AppletInfo>;
export declare const AppletData: z.ZodObject<{
    dataSources: z.ZodRecord<z.ZodObject<{
        data: z.ZodString;
        key: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        data: string;
        key: number;
    }, {
        data: string;
        key: number;
    }>>;
    keys: z.ZodArray<z.ZodArray<z.ZodNumber>>;
    responses: z.ZodArray<z.ZodObject<{
        MRN: z.ZodString;
        activity: z.ZodObject<{
            "@id": z.ZodString;
            name: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            "@id": string;
            name: string;
        }, {
            "@id": string;
            name: string;
        }>;
        created: z.ZodString;
        responseCompleted: z.ZodString;
        data: z.ZodRecord<z.ZodObject<{
            ptr: z.ZodNumber;
            src: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            ptr: number;
            src: string;
        }, {
            ptr: number;
            src: string;
        }>>;
        userId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        data: Record<string, {
            ptr: number;
            src: string;
        }>;
        MRN: string;
        activity: {
            "@id": string;
            name: string;
        };
        created: string;
        responseCompleted: string;
        userId: string;
    }, {
        data: Record<string, {
            ptr: number;
            src: string;
        }>;
        MRN: string;
        activity: {
            "@id": string;
            name: string;
        };
        created: string;
        responseCompleted: string;
        userId: string;
    }>>;
}, "strip", z.ZodTypeAny, {
    keys: number[][];
    dataSources: Record<string, {
        data: string;
        key: number;
    }>;
    responses: {
        data: Record<string, {
            ptr: number;
            src: string;
        }>;
        MRN: string;
        activity: {
            "@id": string;
            name: string;
        };
        created: string;
        responseCompleted: string;
        userId: string;
    }[];
}, {
    keys: number[][];
    dataSources: Record<string, {
        data: string;
        key: number;
    }>;
    responses: {
        data: Record<string, {
            ptr: number;
            src: string;
        }>;
        MRN: string;
        activity: {
            "@id": string;
            name: string;
        };
        created: string;
        responseCompleted: string;
        userId: string;
    }[];
}>;
export declare type AppletData = z.infer<typeof AppletData>;
